@@ -518,11 +518,11 @@ class HardwareStatsTransformerForm(forms.ModelForm):
 
 
 DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,
-                                                              form=DataConstantsTransformerForm,can_delete_extra=True)
+                                                              form=DataConstantsTransformerForm, can_delete_extra=True)
 HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,
-                                                         form=HardwareTransformerForm,can_delete_extra=True)
+                                                         form=HardwareTransformerForm, can_delete_extra=True)
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,
-                                                              form=HardwareStatsTransformerForm,can_delete_extra=True)
+                                                              form=HardwareStatsTransformerForm, can_delete_extra=True)
 
 from django.utils.safestring import mark_safe
 
@@ -575,26 +575,26 @@ class DataTransform(forms.ModelForm):
             print('excpt')
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
         self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
@@ -637,20 +637,28 @@ class DataTransform(forms.ModelForm):
         #     self.nested_data_transformer_form.save(commit)
         if hasattr(self,
                    'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.is_valid()
-            self.nested_constants_form.save(commit)
+            if self.nested_constants_form.is_valid():
+                self.nested_constants_form.save(commit)
+            else:
+                print(self.nested_constants_form.errors)
         if hasattr(self,
                    'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            self.nested_hardware_outputs_form.is_valid()
-            self.nested_hardware_outputs_form.save(commit)
+            if self.nested_hardware_outputs_form.is_valid():
+                self.nested_hardware_outputs_form.save(commit)
+            else:
+                print(self.nested_hardware_outputs_form.errors)
         if hasattr(self,
                    'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            self.nested_hardware_stats_form.is_valid()
-            self.nested_hardware_stats_form.save(commit)
+            if self.nested_hardware_stats_form.is_valid():
+                self.nested_hardware_stats_form.save(commit)
+            else:
+                print(self.nested_hardware_stats_form.errors)
         if hasattr(self,
                    'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            self.nested_data_transformer_form.is_valid()
-            self.nested_data_transformer_form.save(commit)
+            if self.nested_data_transformer_form.is_valid():
+                self.nested_data_transformer_form.save(commit)
+            else:
+                print(self.nested_data_transformer_form.errors)
         root_node.refresh_from_db()
         return root_node
 
@@ -705,26 +713,26 @@ class DataTransformRoot(forms.ModelForm):
             print('exception')
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
         self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
@@ -753,20 +761,28 @@ class DataTransformRoot(forms.ModelForm):
         root_node = super(DataTransformRoot, self).save(commit)
         if hasattr(self,
                    'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.is_valid()
-            self.nested_constants_form.save(commit)
+            if self.nested_constants_form.is_valid():
+                self.nested_constants_form.save(commit)
+            else:
+                print(self.nested_constants_form.errors)
         if hasattr(self,
                    'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            self.nested_hardware_outputs_form.is_valid()
-            self.nested_hardware_outputs_form.save(commit)
+            if self.nested_hardware_outputs_form.is_valid():
+                self.nested_hardware_outputs_form.save(commit)
+            else:
+                print(self.nested_hardware_outputs_form.errors)
         if hasattr(self,
                    'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            self.nested_hardware_stats_form.is_valid()
-            self.nested_hardware_stats_form.save(commit)
+            if self.nested_hardware_stats_form.is_valid():
+                self.nested_hardware_stats_form.save(commit)
+            else:
+                print(self.nested_hardware_stats_form.errors)
         if hasattr(self,
                    'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            self.nested_data_transformer_form.is_valid()
-            self.nested_data_transformer_form.save(commit)
+            if self.nested_data_transformer_form.is_valid():
+                self.nested_data_transformer_form.save(commit)
+            else:
+                print(self.nested_data_transformer_form.errors)
         root_node.refresh_from_db()
         return root_node.get_root()
 
